@@ -21,10 +21,3 @@ from .Plugin import Plugin
 
 class Mod(Plugin):
     """Represents a single mod."""
-    def __init__(self, filename):
-        super(Mod, self).__init__(filename)
-
-    def get_directory(self):
-        """Get the directory path for the mod."""
-        #TODO: Actually implement this if this is necessary.
-        pass
