@@ -20,13 +20,13 @@
 
 
 class PyParadoxException(Exception):
-    """Base exception class. All PyParadox-specific exceptions should inherit
+    """Base exception class.  All PyParadox-specific exceptions should inherit
     from this class.
     """
 
 
-class PySideImportError(PyParadoxException):
-    """Could not import PySide/Qt."""
+class QtImportError(PyParadoxException):
+    """Could not import PySide/PyQt4."""
 
 
 class GameNotExistError(PyParadoxException):
