@@ -21,8 +21,22 @@ import glob
 
 
 def find_dlcs(dlc_path):
+    """Return a list of all ".dlc" files in ``dlc_path``.
+
+    :param dlc_path: Absolute path of directory that needs to be searched.
+    :type dlc_path: str.
+    :returns: List of found DLCs.
+    :rtype: list.
+    """
     return glob.glob(os.path.join(dlc_path, "*.dlc"))
 
 
 def find_mods(mod_path):
+    """Return a list of all ".mod" files in ``mod_path``.
+
+    :param mod_path: Absolute path of directory that needs to be searched.
+    :type mod_path: str.
+    :returns: List of found mods.
+    :rtype: list.
+    """
     return glob.glob(os.path.join(mod_path, "*.mod"))
